@@ -2,6 +2,7 @@ import os
 import sys
 import time
 import logging
+import random
 from tcw.database import session, init_engine
 from tcw.utils import expired_contests
 from tcw.apps.contest.models import Contest
@@ -10,7 +11,7 @@ from sendgrid import SendGridAPIClient
 
 
 # globals #
-logger = logging.getLogger(__name__)
+logger = logging.getLogger('tcw-tasks')
 logging.basicConfig(
     level=logging.INFO,
     format='%(asctime)s|%(name)s|%(levelname)s|%(message)s'
@@ -23,9 +24,10 @@ def main():
         sys.exit(1)
 
     init_engine(uri)
+    logger.info("STARTING")
     while True:
-        time.sleep(60)
         finish_contests()
+        time.sleep(random.randint(30,90))
 
 
 def finish_contests():
@@ -33,14 +35,14 @@ def finish_contests():
         contests = expired_contests()
         logger.info("%d contests pending closure" % len(contests))
     except:
-        logger.info("No contests pending closure")
+        logger.debug("No contests pending closure")
         return
 
     for c in contests:
         try:
             winners = c.pick_winners()
             notify_owner(c, winners)
-            logger.info("Closing contest %s (%s)" % (c.name, c.title))
+            logger.info("Closing contest (%s) %s" % (c.name, c.title))
             session.delete(c)
             session.commit()
         except Exception as x:
@@ -51,8 +53,13 @@ def finish_contests():
 def notify_owner(contest, winners):
     msg = Message(contest=contest, winners=winners).get_message()
     client = SendGridAPIClient(os.getenv('SENDGRID_API_KEY'))
-    response = client.send(message=msg)
-    logger.info("Owner notified successfully" % contest.email)
+    response = client.send(msg)
+    if response.status_code == 200:
+        logger.info("Owner notified successfully")
+        return
+    else:
+        err = "Email error: (%d) %s" % (response.status_code, response.body)
+        raise RuntimeError(err)
 
 
 if __name__ == '__main__':
